==> hoteldruid-mod-pt_2.1.3-2.tar.gz: pt/inizio.php <==
<?php

switch ($messaggio) {

case "Menù principale dell'anno":           $messaggio = "Menu principal do ano"; break;
case "Inserisci una nuova prenotazione":    $messaggio = "Inserir uma nova reserva"; break;
case "prenotazioni del mese di": 		$messaggio = "reservas do mês de"; break;
case "visualizza": 				$messaggio = "visualizar"; break;
case "Gennaio":                             $messaggio = "Janeiro"; break;
case "Febbraio":                            $messaggio = "Fevereiro"; break;
case "Marzo":                               $messaggio = "Março"; break;
case "Aprile":      						$messaggio = "Abril"; break;
case "Maggio":                           	$messaggio = "Maio"; break;
case "Giugno":                            	$messaggio = "Junho"; break;
case "Luglio":                            	$messaggio = "Julho"; break;
case "Agosto":  							$messaggio = "Agosto"; break;
case "Settembre":  							$messaggio = "Setembro"; break;
case "Ottobre":  							$messaggio = "Outubro"; break;
case "Novembre":  							$messaggio = "Novembro"; break;
case "Dicembre":  							$messaggio = "Dezembro"; break;
case "tabella con":  				$messaggio = "tabela com"; break;
case "tutte le prenotazioni":  				$messaggio = "todas as reservas"; break;
case "le spese e le entrate":  				$messaggio = "as entradas e dispesas"; break;
case "i periodi e le tariffe":  			$messaggio = "os períodos e as tarifas"; break;
case "tutti i clienti":  			$messaggio = "todos os clientes"; break;
case "le regole di assegnazione":  		$messaggio = "as regras de atribuição"; break;
case "Inserisci un nuovo cliente":		$messaggio = "Inserir um novo cliente"; break;
case "Spese ed entrate":  			$messaggio = "Despesas e entradas"; break;
case "disponibilità dal":  			$messaggio = "disponibilidade do"; break;
case "al":  					$messaggio = "ao"; break;
case "per":  					$messaggio = "por"; break;
case "persone":	  				$messaggio = "pessoas"; break;
case "controlla":  				$messaggio = "verificar"; break;
case "Inserisci o modifica i prezzi":  		$messaggio = "Inserir ou modificar os preços"; break;
case "Inserisci o modifica le regole di assegnazione":  $messaggio = "Inserir ou modificar as regras de atribuição"; break;
case "Configura e personalizza":	$messaggio = "Configurar e personalizar"; break;
case "richiedi l'anno":  			$messaggio = "pedir o ano"; break;
case "vai":  					$messaggio = "ir"; break;
case "Non esiste l'anno ":  			$messaggio = "O ano "; break;
case " nel database":  				$messaggio = " não existe no banco de dados"; break;
case "Crea l'anno":  				$messaggio = "Criar o ano"; break;
case "Domenica":  				$messaggio = "Domingo"; break;
case "Lunedì":  				$messaggio = "Segunda-feira"; break;
case "Martedì":  				$messaggio = "Terça-feira"; break;
case "Mercoledì":  				$messaggio = "Quarta-feira"; break;
case "Giovedì":  				$messaggio = "Quinta-feira"; break;
case "Venerdì":  				$messaggio = "Sexta-feira"; break;
case "Sabato":	 		 		$messaggio = "Sábado"; break;
case "come giorno di inizio/fine locazione":	$messaggio = "como o dia de ínicio/fim da estadia"; break;
case "con periodi":  				$messaggio = "com períodos"; break;
case "settimanali":  				$messaggio = "semanais"; break;
case "giornalieri":  				$messaggio = "diários"; break;
case "e prenotazioni da":  			$messaggio = "e reservas de"; break;
case "a":  					$messaggio = "a"; break;
case "anno successivo": 			$messaggio = "próximo ano"; break;
case "anni successivi":  			$messaggio = "próximos anos"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Importar do ano passado reservas, tarifas (inclusive os custos adicionais), privilégios dos usuários e regras de atribuição."; break;
case "Anno ":  					$messaggio = "Ano "; break;
case " creato":  				$messaggio = " criado"; break;
case "Non ci sono periodi che riguardano il ":  $messaggio = "Não tem períodos que se relacionam com o "; break;
case " nel ":  					$messaggio = " no "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":	$messaggio = ", ou o dia de ínicio/fim da estadia era diferente. Apenas dados sobre custos adicional, depósito, os nomes das tarifas, privilégios dos usuários e as regras de atribuição 2 e 3 foram importadas"; break;
case "Attenzione</b></font>: i periodi del ":  	$messaggio = "Atenção</b></font>: Os períodos de "; break;
case " finivano dopo quelli del ":  		$messaggio = " terminaram após aqueles do "; break;
case " e vi erano":  				$messaggio = " e eram"; break;
case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "reservas que terminaram depois do limite dado ao "; break;
case ", queste prenotazioni non sono state importate":	$messaggio = ", estas reservas não foram importadas"; break;
case "Anno già creato": 			$messaggio = "Ano já criado"; break;
case " Do":  					$messaggio = " Do"; break;
case " Lu":  					$messaggio = " 2a"; break;
case " Ma":  					$messaggio = " 3a"; break;
case " Me":  					$messaggio = " 4a"; break;
case " Gi":  					$messaggio = " 5a"; break;
case " Ve":  					$messaggio = " 6a"; break;
case " Sa":  					$messaggio = " Sá"; break;
case "Gen":  					$messaggio = "Jan"; break;
case "Feb":  					$messaggio = "Fev"; break;
case "Mar":  					$messaggio = "Mar"; break;
case "Apr":  					$messaggio = "Abr"; break;
case "Mag":  					$messaggio = "Mai"; break;
case "Giu":  					$messaggio = "Jun"; break;
case "Lug":  					$messaggio = "Jul"; break;
case "Ago":  					$messaggio = "Ago"; break;
case "Set":  					$messaggio = "Set"; break;
case "Ott":  					$messaggio = "Out"; break;
case "Nov":  					$messaggio = "Nov"; break;
case "Dic":  					$messaggio = "Dez"; break;
case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "O formato do ano pedido está errado"; break;
case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "Os mesese foram indicados incorrectamente. Foram inseridos os meses de Janeiro a Dezembro"; break;
case "N&deg;":  				$messaggio = "N°"; break;
case "Cognome del cliente":  			$messaggio = "Sobrenome do cliente"; break;
case "Data iniziale":  				$messaggio = "Data inicial"; break;
case "Data finale":  				$messaggio = "Data final"; break;
case "Tariffa completa":  			$messaggio = "Tarifa completa"; break;
case "Da pagare":  				$messaggio = "A pagar"; break;
case "Pers":  					$messaggio = "Pess"; break;
case "Registra":  				$messaggio = "Registrar"; break;
case "Entrata":  				$messaggio = "Entrada"; break;
case "Uscita":  				$messaggio = "Saída"; break;
case "Entrata e pagato":  			$messaggio = "Entrou e pagou"; break;
case "Uscita e pagato":  			$messaggio = "Saíu e pagou"; break;
case "mostra tutte le date":  			$messaggio = "mostrar todas as datas"; break;
case "Utente":  				$messaggio = "Usuário"; break;
case "Esci":  					$messaggio = "Sair"; break;
case "Messaggi":  				$messaggio = "Mensagens"; break;
case "<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al":	$messaggio = "<span class=\"colred\">Aviso</span>: é aconselhável esperar até"; break;
case "per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "para criar o novo ano. Entretanto, você pode adicionar outros períodos"; break;
case "dalla":  					$messaggio = "da"; break;
case "tabella con i periodi e le tariffe":  	$messaggio = "tabela com os períodos e tarifas"; break;
case "anche senza creare un nuovo anno":  	$messaggio = "mesmo sem criar um novo ano"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "Falta o privilégio de escrita na pasta dati"; break;
case "le statistiche":  			$messaggio = "as estatísticas"; break;
case "inventario e magazzini":  		$messaggio = "inventário e armazéns"; break;
case "obsoleti":  				$messaggio = "obsoletos"; break;
case "Ultimo aggiornamento":  			$messaggio = "Última atualização"; break;
case "Aggiorna":  				$messaggio = "Atualização"; break;
case "i documenti salvati":  			$messaggio = "os documentos salvos"; break;
case "Punto vendita":  				$messaggio = "Punto de venda"; break;
case "Non ho i permessi per creare nuove tabelle nel database":	$messaggio = "Falta o privilégio para criar novas tabelas no banco de dados"; break;
case "Benvenuto a HOTELDRUID":  		$messaggio = "Bem-vindo ao HotelDruid"; break;
case "Scegli la lingua":  			$messaggio = "Escolher a língua"; break;
case "crea il database":  			$messaggio = "criar o banco de dados"; break;
case "Promemoria":  				$messaggio = "Lembrete"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-pt_3.0.8-1.tar.gz: pt/inizio.php <==
<?php

switch ($messaggio) {

case "Menù principale dell'anno":           $messaggio = "Menu principal do ano"; break;
case "Inserisci una nuova prenotazione":    $messaggio = "Adicionar reserva"; break;
case "prenotazioni del mese di": 		$messaggio = "reservas para o mês de"; break;
case "visualizza": 				$messaggio = "visualizar"; break;
case "Gennaio":                             $messaggio = "Janeiro"; break;
case "Febbraio":                            $messaggio = "Fevereiro"; break;
case "Marzo":                               $messaggio = "Março"; break;
case "Aprile":      						$messaggio = "Abril"; break;
case "Maggio":                           	$messaggio = "Maio"; break;
case "Giugno":                            	$messaggio = "Junho"; break;
case "Luglio":                            	$messaggio = "Julho"; break;
case "Agosto":  							$messaggio = "Agosto"; break;
case "Settembre":  							$messaggio = "Setembro"; break;
case "Ottobre":  							$messaggio = "Outubro"; break;
case "Novembre":  							$messaggio = "Novembro"; break;
case "Dicembre":  							$messaggio = "Dezembro"; break;
case "tabella con":  				$messaggio = "tabela com"; break;
case "tutte le prenotazioni":  				$messaggio = "todas as reservas"; break;
case "le spese e le entrate":  				$messaggio = "as entradas e dispesas"; break;
case "i periodi e le tariffe":  			$messaggio = "os períodos e as tarifas"; break;
case "tutti i clienti":  			$messaggio = "todos os clientes"; break;
case "le regole di assegnazione":  		$messaggio = "as regras de atribuição"; break;
case "Inserisci un nuovo cliente":		$messaggio = "Acrescentar um novo cliente"; break;
case "Spese ed entrate":  			$messaggio = "Despesas e entradas"; break;
case "disponibilità dal":  			$messaggio = "disponibilidade do"; break;
case "al":  					$messaggio = "ao"; break;
case "per":  					$messaggio = "para"; break;
case "persone":	  				$messaggio = "pessoas"; break;
case "controlla":  				$messaggio = "verificar"; break;
case "Inserisci o modifica i prezzi":  		$messaggio = "Introduzir ou modificar preços"; break;
case "Inserisci o modifica le regole di assegnazione":  $messaggio = "Introduzir ou modificar regras de atribuição"; break;
case "Configura e personalizza":	$messaggio = "Configurar e personalizar"; break;
case "richiedi l'anno":  			$messaggio = "solicitar o ano"; break;
case "vai":  					$messaggio = "OK"; break;
case "Non esiste l'anno ":  			$messaggio = "O ano "; break;
case " nel database":  				$messaggio = " não existe no banco de dados"; break;
case "Crea l'anno":  				$messaggio = "Criar o ano"; break;
case "Domenica":  				$messaggio = "Domingo"; break;
case "Lunedì":  				$messaggio = "Segunda-feira"; break;
case "Martedì":  				$messaggio = "Terça-feira"; break;
case "Mercoledì":  				$messaggio = "Quarta-feira"; break;
case "Giovedì":  				$messaggio = "Quinta-feira"; break;
case "Venerdì":  				$messaggio = "Sexta-feira"; break;
case "Sabato":	 		 		$messaggio = "Sábado"; break;
case "come giorno di inizio/fine locazione":	$messaggio = "como o dia de ínicio/fim da estadia"; break;
case "con periodi":  				$messaggio = "com períodos"; break;
case "settimanali":  				$messaggio = "semanais"; break;
case "giornalieri":  				$messaggio = "diários"; break;
case "e prenotazioni da":  			$messaggio = "e reservas entre"; break;
case "a":  					$messaggio = "e"; break;
case "anno successivo": 			$messaggio = "próximo ano"; break;
case "anni successivi":  			$messaggio = "próximos anos"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Importar tarifas, reservas (inclusive os custos adicionais), privilégios dos usuários e regras de atribuição do ano passado."; break;
case "Anno ":  					$messaggio = "Ano "; break;
case " creato":  				$messaggio = " criado"; break; 
case "Non ci sono periodi che riguardano il ":  $messaggio = "Não existem períodos relativos ao "; break;
case " nel ":  					$messaggio = " no "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":	$messaggio = ", ou o dia de ínicio/fim da estadia era diferente. Só foram importados dados relativos a custos adicionais, depósito, nome da tarifa, privilégios do utilizador e regras de atribuição 2 e 3"; break;
case "Attenzione</b></font>: i periodi del ":  	$messaggio = "Atenção</b></font>: Os períodos de "; break;
case " finivano dopo quelli del ":  		$messaggio = " terminaram após aqueles do "; break;
case " e vi erano":  				$messaggio = " e eram"; break;
case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "reservas que terminaram depois do limite dado ao "; break;
case ", queste prenotazioni non sono state importate":	$messaggio = ", estas reservas não foram importadas"; break;
case "Anno già creato": 			$messaggio = "Ano já criado"; break;
case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "O formato do ano solicitado está errado"; break;
case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "Os mesese foram indicados errado. Foram inseridos os meses de Janeiro a Dezembro"; break;
case "N&deg;":  				$messaggio = "N.º"; break;
case "Cognome del cliente":  			$messaggio = "Sobrenome do cliente"; break;
case "Data iniziale":  				$messaggio = "Data inicial"; break;
case "Data finale":  				$messaggio = "Data final"; break;
case "Tariffa completa":  			$messaggio = "Tarifa completa"; break;
case "Da pagare":  				$messaggio = "A pagar"; break;
case "Pers":  					$messaggio = "Pess"; break;
case "Registra":  				$messaggio = "Registrar"; break;
case "Entrata":  				$messaggio = "Entrada"; break;
case "Uscita":  				$messaggio = "Saída"; break;
case "Entrata e pagato":  			$messaggio = "Entrou e pagou"; break;
case "Uscita e pagato":  			$messaggio = "Saíu e pagou"; break;
case "mostra tutte le date":  			$messaggio = "mostrar todas as datas"; break;
case "Utente":  				$messaggio = "Usuário"; break;
case "Esci":  					$messaggio = "Sair"; break;
case "Messaggi":  				$messaggio = "Mensagens"; break;
case "<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al":	$messaggio = "<span class=\"colred\">Aviso</span>: é aconselhável esperar até"; break;
case "per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "para criar o novo ano. Entretanto, você pode adicionar outros períodos"; break;
case "dalla":  					$messaggio = "da"; break;
case "tabella con i periodi e le tariffe":  	$messaggio = "tabela com os períodos e tarifas"; break;
case "anche senza creare un nuovo anno":  	$messaggio = "mesmo sem criar um novo ano"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "Falta o privilégio de escrita na pasta dati"; break;
case "le statistiche":  			$messaggio = "as estatísticas"; break;
case "inventario e magazzini":  		$messaggio = "inventário e armazéns"; break;
case "obsoleti":  				$messaggio = "obsoletos"; break;
case "Ultimo aggiornamento":  			$messaggio = "Última atualização"; break;
case "Aggiorna":  				$messaggio = "Atualização"; break;
case "i documenti salvati":  			$messaggio = "os documentos salvos"; break;
case "Punto vendita":  				$messaggio = "Punto de venda"; break;
case "Non ho i permessi per creare nuove tabelle nel database":	$messaggio = "Falta o privilégio para criar novas tabelas no banco de dados"; break;
case "Benvenuto a HOTELDRUID":  		$messaggio = "Bem-vindo ao HotelDruid"; break;
case "Scegli la lingua":  			$messaggio = "Escolher a língua"; break;
case "crea il database":  			$messaggio = "criar o banco de dados"; break;
case "Promemoria":  				$messaggio = "Lembrete"; break;
case "Questo utente non ha i privilegi per creare nuovi anni":	$messaggio = "Este usuário não tem privilégios para criar novos anos"; break;
case "Avviso":  				$messaggio = "Aviso"; break;
case "nel database sono ancora disponibili periodi solo per meno di":	$messaggio = "no banco de dados ainda há disponibilidade para períodos por menos de"; break;
case "mesi":  					$messaggio = "meses"; break;
case "OK, ho capito":  				$messaggio = "OK, entendi"; break;
case "Crea Anno":  				$messaggio = "Criar ano"; break;
case "Nota":  					$messaggio = "Nota"; break;
case "l'anno":  				$messaggio = "o ano"; break;
case "verrà archiviato automaticamente il":  	$messaggio = "será automaticamente arquivado no"; break;
case "nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "entretanto, podem ser acrescentados períodos para além de "; break;
case "ricordarsi di tornare al":  		$messaggio = "lembre-se de voltar ao"; break;
case "una volta conclusa la consultazione del":	$messaggio = "uma vez terminada a consulta do"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
